@@ -12,6 +12,7 @@ logging.basicConfig(format='%(asctime)s %(levelname)s %(message)s',
 import yaml
 import MySQLdb
 import MySQLdb.cursors
+import cPickle as pickle
 # mine
 import hwrt
 from hwrt.HandwrittenData import HandwrittenData
@@ -21,7 +22,7 @@ import hwrt.features as features
 import hwrt.data_multiplication as data_multiplication
 
 
-def _fetch_data(raw_data_id):
+def _fetch_data_from_server(raw_data_id):
     """Get the data from raw_data_id from the server.
     :returns: The ``data`` if fetching worked, ``None`` if it failed."""
     # Import configuration file
@@ -44,6 +45,17 @@ def _fetch_data(raw_data_id):
     return cursor.fetchone()
 
 
+def _get_data_from_rawfile(path_to_data, raw_data_id):
+    """Get a HandwrittenData object that has ``raw_data_id`` from a pickle file
+       ``path_to_data``."""
+    loaded = pickle.load(open(path_to_data))
+    raw_datasets = loaded['handwriting_datasets']
+    for raw_dataset in raw_datasets:
+        if raw_dataset['formula_id'] == raw_data_id:
+            return raw_dataset['handwriting']
+    return None
+
+
 def _get_system(model_folder):
     """Return the preprocessing description, the feature description and the
        model description."""
@@ -166,18 +178,25 @@ def get_parser():
 
 if __name__ == '__main__':
     args = get_parser().parse_args()
-
-    # do something
-    data = _fetch_data(args.id)
+    data = _fetch_data_from_server(args.id)
     if data is None:
         logging.info("RAW_DATA_ID %i does not exist or "
                      "database connection did not work.", args.id)
-    else:
         # The data was not on the server / the connection to the server did
         # not work. So try it again with the model data
         preprocessing_desc, _, _ = _get_system(args.model)
         raw_datapath = os.path.join(utils.get_project_root(),
                                     preprocessing_desc['data-source'])
-
+        handwriting = _get_data_from_rawfile(raw_datapath, args.id)
+        if handwriting is None:
+            logging.info("Recording with ID %i was not found in %s",
+                         args.id,
+                         raw_datapath)
+        else:
+            print("hwrt version: %s" % hwrt.__version__)
+            display_data(handwriting.raw_data_json,
+                         handwriting.formula_id,
+                         args.model)
+    else:
         print("hwrt version: %s" % hwrt.__version__)
         display_data(data['data'], data['id'], args.model)
